"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _fieldeditortestutils = require("@contentful/field-editor-test-utils");
require("@testing-library/jest-dom/extend-expect");
const _react1 = require("@testing-library/react");
const _BooleanEditor = require("./BooleanEditor");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
(0, _react1.configure)({
    testIdAttribute: 'data-test-id'
});
describe('BooleanEditor', ()=>{
    afterEach(_react1.cleanup);
    it('renders inputs for true and false values', ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)();
        const { container, getByLabelText } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_BooleanEditor.BooleanEditor, {
            field: field,
            isInitiallyDisabled: false
        }));
        const $inputs = container.querySelectorAll('input[type="radio"]');
        expect($inputs).toHaveLength(2);
        [
            {
                value: 'true',
                label: 'Yes'
            },
            {
                value: 'false',
                label: 'No'
            }
        ].forEach((item, index)=>{
            expect($inputs[index].value).toEqual(item.value);
            getByLabelText(item.label);
        });
    });
    it('calls setValue and removeValue properly', ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            jest.spyOn(field, 'setValue');
            jest.spyOn(field, 'removeValue');
            return {
                ...field
            };
        });
        const { getByLabelText, queryByText, getByText } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_BooleanEditor.BooleanEditor, {
            field: field,
            isInitiallyDisabled: false,
            parameters: {
                invocation: {},
                installation: {},
                instance: {
                    trueLabel: 'Yeah, obviously',
                    falseLabel: 'No, of course'
                }
            }
        }));
        expect(queryByText('Clear')).not.toBeInTheDocument();
        _react1.fireEvent.click(getByLabelText('Yeah, obviously'));
        expect(field.setValue).toHaveBeenCalledWith(true);
        _react1.fireEvent.click(getByLabelText('No, of course'));
        expect(field.setValue).toHaveBeenCalledWith(false);
        expect(field.removeValue).toHaveBeenCalledTimes(0);
        _react1.fireEvent.click(getByText('Clear'));
        expect(field.removeValue).toHaveBeenCalledTimes(1);
    });
    it('all interactive elements are disabled if field is disabled', ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            return field;
        }, true);
        const { getByTestId, getByLabelText } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_BooleanEditor.BooleanEditor, {
            field: field,
            isInitiallyDisabled: true
        }));
        expect(getByLabelText('Yes')).toBeDisabled();
        expect(getByLabelText('No')).toBeDisabled();
        expect(getByTestId('boolean-editor-clear')).toBeDisabled();
    });
});
