import * as React from 'react';
import { TextLink, Flex, Radio } from '@contentful/f36-components';
import { FieldConnector } from '@contentful/field-editor-shared';
import get from 'lodash/get';
import { nanoid } from 'nanoid';
export function BooleanEditor(props) {
    const { field } = props;
    const options = [
        {
            value: true,
            label: get(props.parameters, [
                'instance',
                'trueLabel'
            ], 'Yes'),
            id: nanoid(6)
        },
        {
            value: false,
            label: get(props.parameters, [
                'instance',
                'falseLabel'
            ], 'No'),
            id: nanoid(6)
        }
    ];
    return /*#__PURE__*/ React.createElement(FieldConnector, {
        debounce: 0,
        field: field,
        isInitiallyDisabled: props.isInitiallyDisabled
    }, ({ disabled, value, setValue })=>{
        const setOption = (value)=>{
            setValue(value === 'true' ? true : false);
        };
        const clearOption = ()=>{
            setValue(null);
        };
        return /*#__PURE__*/ React.createElement(Flex, {
            testId: "boolean-editor",
            alignItems: "center",
            marginTop: "spacingS"
        }, options.map((option)=>{
            const id = [
                'entity',
                field.id,
                field.locale,
                option.value,
                option.id
            ].join('.');
            const checked = value === option.value;
            return /*#__PURE__*/ React.createElement(Flex, {
                marginRight: "spacingM",
                key: id
            }, /*#__PURE__*/ React.createElement(Radio, {
                id: id,
                isDisabled: disabled,
                value: option.value === undefined ? '' : String(option.value),
                isChecked: checked,
                onChange: (e)=>{
                    if (e.target.checked) {
                        setOption(e.target.value);
                    }
                }
            }, option.label));
        }), value !== undefined && /*#__PURE__*/ React.createElement(TextLink, {
            as: "button",
            testId: "boolean-editor-clear",
            isDisabled: disabled,
            onClick: clearOption
        }, "Clear"));
    });
}
BooleanEditor.defaultProps = {
    isInitiallyDisabled: true
};
